pub struct ParserConfig {
pub worker_count: usize,
pub queue_capacity: usize,
}Expand description
Configuration for the parser workers.
This struct holds settings specific to the response parsing subsystem.
Fields
worker_count: usizeThe number of parser worker tasks to spawn.
queue_capacity: usizeThe capacity of the internal parse queue per worker.
Implementations
Sourceimpl ParserConfig
impl ParserConfig
Sourcepub fn with_worker_count(self, count: usize) -> Self
pub fn with_worker_count(self, count: usize) -> Self
Sets the number of parser workers.
Sourcepub fn with_queue_capacity(self, capacity: usize) -> Self
pub fn with_queue_capacity(self, capacity: usize) -> Self
Sets the internal queue capacity per worker.