pub struct CrawlerContext<S, I>where
S: Spider<Item = I>,
I: ScrapedItem,{
pub scheduler: Arc<Scheduler>,
pub stats: Arc<StatCollector>,
pub spider: Arc<S>,
pub spider_state: Arc<S::State>,
pub pipelines: Arc<Vec<Box<dyn Pipeline<I>>>>,
}Expand description
Aggregated context shared across all crawler tasks.
This struct bundles together all the Arc-wrapped components that need to be shared between the crawler’s various async tasks. Instead of cloning each Arc individually, we can clone this context with a single Arc::clone().
Fields
scheduler: Arc<Scheduler>stats: Arc<StatCollector>spider: Arc<S>spider_state: Arc<S::State>pipelines: Arc<Vec<Box<dyn Pipeline<I>>>>Implementations
Sourceimpl<S, I> CrawlerContext<S, I>where
S: Spider<Item = I>,
I: ScrapedItem,
impl<S, I> CrawlerContext<S, I>where
S: Spider<Item = I>,
I: ScrapedItem,